package jp.co.intra_mart.cookbook.im_cookbook_127124.oauth.client.service.processor.impl;

import java.util.ServiceLoader;

import jp.co.intra_mart.system.oauth.client.service.processor.OAuthAuthzCodeRequestProcessor;
import jp.co.intra_mart.system.oauth.client.service.processor.OAuthRefreshAccessTokenRequestProcessor;
import jp.co.intra_mart.system.oauth.client.service.processor.impl.StandardAuthzCodeRequestProcessor;
import jp.co.intra_mart.system.oauth.client.service.processor.impl.StandardOAuthRequestProcessorFactory;
import jp.co.intra_mart.system.oauth.client.service.processor.impl.StandardRefreshAccessTokenRequestProcessor;

/**
 * Box向けのOAuthRequestProcessorFactoryです。<br />
 * {@link ServiceLoader}により読みこまれます、以下のファイルに設定が行われています。<br />
 * src/main/resources/META-INF/services/jp.co.intra_mart.system.oauth.client.service.processor.OAuthRequestProcessorFactory
 */
public class BoxOAuthRequestProcessorFactory extends StandardOAuthRequestProcessorFactory {

    private final OAuthAuthzCodeRequestProcessor authzCodeProcessor;

    private final OAuthRefreshAccessTokenRequestProcessor refreshTokneProcessor;

    public BoxOAuthRequestProcessorFactory() {
        authzCodeProcessor = new StandardAuthzCodeRequestProcessor(BoxConstants.PROVIDER_TYPE);
        refreshTokneProcessor = new StandardRefreshAccessTokenRequestProcessor(BoxConstants.PROVIDER_TYPE);
    }

    @Override
    public OAuthAuthzCodeRequestProcessor getAuthzCodeRequestProcessor() {
        return authzCodeProcessor;
    }

    @Override
    public String getProviderType() {
        return BoxConstants.PROVIDER_TYPE;
    }

    @Override
    public OAuthRefreshAccessTokenRequestProcessor getRefreshAccessTokenRequestProcessor() {
        return refreshTokneProcessor;
    }

}
